<?php

/*********************************************************************************************************
*
*  PM from new user (/inc/plugins/pmfromnewuser.php)
*  Author: MYBB PL
*  Copyright: 215 @ MYBB PL @ All rights reserved
*  
*  Website: https://mybboard.pl/
*  License: licence.txt
*  Description: Allows users to disable receiving pm from new users.
*
*********************************************************************************************************/
/*********************************************************************************************************
*
* This file is part of PM from new user plugin for MyBB.
* Copyright (C) 20155 MYBB PL
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
*
*********************************************************************************************************/

if(!defined("IN_MYBB"))
{
	die("Direct initialization of this file is not allowed.<br /><br />Please make sure IN_MYBB is defined.");
}

$plugins->add_hook("usercp_options_end", "pmfromnewuser_options_end");
$plugins->add_hook("usercp_do_options_start", "pmfromnewuser_do_options_end");

$plugins->add_hook("private_send_do_send", "pmfromnewuser_send_do_send");

function pmfromnewuser_info()
{
    global $lang;
    $lang->load("config_pmfromnewuser");
	
	return array(
		"name"					=> $lang->pmfromnewuser_name,
		"description"			=> $lang->pmfromnewuser_desc,
		"website"				=> "https://mybboard.pl/",
		"author"				=> "MYBB PL",
		"authorsite"			=> "https://mybboard.pl/",
		"version"				=> "1.1",
		"codename" 			=> "",
		"compatibility"		=> "18*",
	);
}

function pmfromnewuser_is_installed()
{
	global $db;
	
	return $db->field_exists("pmfromnewuser", "users"));
}

function pmfromnewuser_install()
{
	global $db, $lang;
	$lang->load("config_pmfromnewuser");
	
	pmfromnewuser_uninstall();
	
	if(!$db->field_exists("pmfromnewuser", "users"))
	{
		$db->write_query("ALTER TABLE ".TABLE_PREFIX."users ADD pmfromnewuser smallint(1) NOT NULL DEFAULT '1';");
	}
	
	
	$max_disporder = $db->fetch_field($db->simple_select("settinggroups", "MAX(disporder) AS max_disporder"), "max_disporder");
	
	$settinggroup = array(
		"gid"					=> "NULL",
		"name" 				=> "pmfromnewuser", 
		"title" 					=> $db->escape_string($lang->pmfromnewuser_setting),
		"description" 		=> $db->escape_string($lang->pmfromnewuser_setting_desc),
		"disporder" 			=> $max_disporder + 1,
		"isdefault" 			=> "0",
	);
	$gid = $db->insert_query("settinggroups", $settinggroup);
	
	$settings = array();
	
	$settings[] = array(
		"sid"						=> "NULL",
		"name"					=> "pmfromnewuser_posts",
		"title"					=> $db->escape_string($lang->pmfromnewuser_setting_posts),
		"description"			=> $db->escape_string($lang->pmfromnewuser_setting_posts_desc),
		"optionscode"		=> "text",
		"value"					=> "10",
		"disporder"			=> $disporder++,
		"gid"						=> $gid,
		"isdefault"			=> "0",
	);
	
	$settings[] = array(
		"sid"						=> "NULL",
		"name"					=> "pmfromnewuser_days",
		"title"					=> $db->escape_string($lang->pmfromnewuser_setting_days),
		"description"			=> $db->escape_string($lang->pmfromnewuser_setting_days_desc),
		"optionscode"		=> "text",
		"value"					=> "10",
		"disporder"			=> $disporder++,
		"gid"						=> $gid,
		"isdefault"			=> "0",
	);
	
	$db->insert_query_multiple("settings", $settings);
	
	rebuild_settings();
}

function pmfromnewuser_uninstall()
{
	global $db;

	if($db->field_exists("pmfromnewuser", "users"))
	{
		$db->write_query("ALTER TABLE ".TABLE_PREFIX."users DROP pmfromnewuser;");
	}
	
	$db->delete_query('settinggroups', 'name = \'pmfromnewuser\'');
	$db->delete_query('settings', 'name LIKE \'%pmfromnewuser%\'');
	rebuild_settings();
	$db->delete_query('templates', 'title LIKE (\'%pmfromnewuser%\')');
}

function pmfromnewuser_activate()
{
	pmfromnewuser_deactivate();
			
	find_replace_templatesets("usercp_options", '#'.preg_quote('{$pms_from_buddys}').'#', '<tr>
<td valign="top" width="1"><input type="checkbox" class="checkbox" name="pmfromnewuser" id="pmfromnewuser" value="1" {$pmfromnewusercheck} /></td>
<td><span class="smalltext"><label for="pmfromnewuser">{$lang->pmfromnewuser}</label></span></td>
</tr>'."\n".'{$pms_from_buddys}');
}

function pmfromnewuser_deactivate()
{
	include MYBB_ROOT."/inc/adminfunctions_templates.php";
	
	find_replace_templatesets('usercp_options', '#' . preg_quote('<tr>
<td valign="top" width="1"><input type="checkbox" class="checkbox" name="pmfromnewuser" id="pmfromnewuser" value="1" {$pmfromnewusercheck} /></td>
<td><span class="smalltext"><label for="pmfromnewuser">{$lang->pmfromnewuser}</label></span></td>
</tr>'."\n") . '#', '', 0);
}

function pmfromnewuser_options_end()
{
    global $user, $pmfromnewusercheck, $lang;
	$lang->load("pmfromnewuser");
	
	if($user['pmfromnewuser'] == 1)
	{
		$pmfromnewusercheck = "checked=\"checked\"";
	}
	else
	{
		$pmfromnewusercheck = "";
	}
}

function pmfromnewuser_do_options_end()
{
    global $mybb, $db;
	
	
	$db->update_query("users", array('pmfromnewuser' => $db->escape_string($mybb->get_input("pmfromnewuser", 1))), 'uid='.$mybb->user['uid']);
}

function pmfromnewuser_send_do_send()
{
    global $mybb, $db, $lang;
	$lang->load("pmfromnewuser");	
	
	if($mybb->settings['pmfromnewuser_posts'] < $mybb->user['postnum'])
	{
			return;
	}
	
	if($mybb->settings['pmfromnewuser_days'] * (60*60*24) < TIME_NOW - $mybb->user['regdate'])
	{
			return;
	}
	
	$names = explode("," , $mybb->get_input("to"));
	$names = array_map("trim", $names);
	$names = implode("', '" , $names);

	$query = $db->simple_select("users", "username,pmfromnewuser", "username in ('{$names}') AND pmfromnewuser = '0'");
	if($db->num_rows($query)) 
	{
			error($lang->pmfromnewuser_info);
	}
}